# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/device.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import meta_pb2 as voltha__protos_dot_meta__pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/device.proto',
  package='voltha',
  syntax='proto3',
  serialized_options=b'\n\023org.opencord.volthaB\014VolthaDeviceZ.github.com/opencord/voltha-protos/v4/go/voltha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1avoltha_protos/device.proto\x12\x06voltha\x1a\x19google/protobuf/any.proto\x1a\x1avoltha_protos/common.proto\x1a\x18voltha_protos/meta.proto\x1a\x1fvoltha_protos/openflow_13.proto\"\xc8\x01\n\nDeviceType\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tvendor_id\x18\x05 \x01(\t\x12\x12\n\nvendor_ids\x18\x06 \x03(\t\x12\x0f\n\x07\x61\x64\x61pter\x18\x02 \x01(\t\x12 \n\x18\x61\x63\x63\x65pts_bulk_flow_update\x18\x03 \x01(\x08\x12\'\n\x1f\x61\x63\x63\x65pts_add_remove_flow_updates\x18\x04 \x01(\x08\x12+\n#accepts_direct_logical_flows_update\x18\x07 \x01(\x08\"0\n\x0b\x44\x65viceTypes\x12!\n\x05items\x18\x01 \x03(\x0b\x32\x12.voltha.DeviceType\"\x9f\x01\n\x08PmConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04type\x18\x02 \x01(\x0e\x32\x17.voltha.PmConfig.PmType\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x13\n\x0bsample_freq\x18\x04 \x01(\r\"8\n\x06PmType\x12\x0b\n\x07\x43OUNTER\x10\x00\x12\t\n\x05GAUGE\x10\x01\x12\t\n\x05STATE\x10\x02\x12\x0b\n\x07\x43ONTEXT\x10\x03\"k\n\rPmGroupConfig\x12\x12\n\ngroup_name\x18\x01 \x01(\t\x12\x12\n\ngroup_freq\x18\x02 \x01(\r\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12!\n\x07metrics\x18\x04 \x03(\x0b\x32\x10.voltha.PmConfig\"\xbf\x01\n\tPmConfigs\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65\x66\x61ult_freq\x18\x02 \x01(\r\x12\x16\n\x07grouped\x18\x03 \x01(\x08\x42\x05\xe8\xf6\xcd\x1d\x01\x12\x1c\n\rfreq_override\x18\x04 \x01(\x08\x42\x05\xe8\xf6\xcd\x1d\x01\x12%\n\x06groups\x18\x05 \x03(\x0b\x32\x15.voltha.PmGroupConfig\x12!\n\x07metrics\x18\x06 \x03(\x0b\x32\x10.voltha.PmConfig\x12\x10\n\x08max_skew\x18\x07 \x01(\r\"\x89\x01\n\x05Image\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04hash\x18\x03 \x01(\t\x12\x18\n\x10install_datetime\x18\x04 \x01(\t\x12\x11\n\tis_active\x18\x05 \x01(\x08\x12\x14\n\x0cis_committed\x18\x06 \x01(\x08\x12\x10\n\x08is_valid\x18\x07 \x01(\x08\"&\n\x06Images\x12\x1c\n\x05image\x18\x01 \x03(\x0b\x32\r.voltha.Image\"\xdd\x06\n\rImageDownload\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0b\n\x03\x63rc\x18\x04 \x01(\r\x12@\n\x0e\x64ownload_state\x18\x05 \x01(\x0e\x32(.voltha.ImageDownload.ImageDownloadState\x12\x15\n\rimage_version\x18\x06 \x01(\t\x12\x18\n\x10\x64ownloaded_bytes\x18\x07 \x01(\r\x12@\n\x06reason\x18\x08 \x01(\x0e\x32\x30.voltha.ImageDownload.ImageDownloadFailureReason\x12\x17\n\x0f\x61\x64\x64itional_info\x18\t \x01(\t\x12\x13\n\x0bsave_config\x18\n \x01(\x08\x12\x11\n\tlocal_dir\x18\x0b \x01(\t\x12=\n\x0bimage_state\x18\x0c \x01(\x0e\x32(.voltha.ImageDownload.ImageActivateState\x12\x11\n\tfile_size\x18\r \x01(\r\"\xb7\x01\n\x12ImageDownloadState\x12\x14\n\x10\x44OWNLOAD_UNKNOWN\x10\x00\x12\x16\n\x12\x44OWNLOAD_SUCCEEDED\x10\x01\x12\x16\n\x12\x44OWNLOAD_REQUESTED\x10\x02\x12\x14\n\x10\x44OWNLOAD_STARTED\x10\x03\x12\x13\n\x0f\x44OWNLOAD_FAILED\x10\x04\x12\x18\n\x14\x44OWNLOAD_UNSUPPORTED\x10\x05\x12\x16\n\x12\x44OWNLOAD_CANCELLED\x10\x06\"\x86\x01\n\x1aImageDownloadFailureReason\x12\x0c\n\x08NO_ERROR\x10\x00\x12\x0f\n\x0bINVALID_URL\x10\x01\x12\x0f\n\x0b\x44\x45VICE_BUSY\x10\x02\x12\x16\n\x12INSUFFICIENT_SPACE\x10\x03\x12\x11\n\rUNKNOWN_ERROR\x10\x04\x12\r\n\tCANCELLED\x10\x05\"\x8c\x01\n\x12ImageActivateState\x12\x11\n\rIMAGE_UNKNOWN\x10\x00\x12\x12\n\x0eIMAGE_INACTIVE\x10\x01\x12\x14\n\x10IMAGE_ACTIVATING\x10\x02\x12\x10\n\x0cIMAGE_ACTIVE\x10\x03\x12\x13\n\x0fIMAGE_REVERTING\x10\x04\x12\x12\n\x0eIMAGE_REVERTED\x10\x05\"6\n\x0eImageDownloads\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.voltha.ImageDownload\"\xa2\x04\n\x04Port\x12\x0f\n\x07port_no\x18\x01 \x01(\r\x12\r\n\x05label\x18\x02 \x01(\t\x12#\n\x04type\x18\x03 \x01(\x0e\x32\x15.voltha.Port.PortType\x12-\n\x0b\x61\x64min_state\x18\x05 \x01(\x0e\x32\x18.common.AdminState.Types\x12-\n\x0boper_status\x18\x06 \x01(\x0e\x32\x18.common.OperStatus.Types\x12\x11\n\tdevice_id\x18\x07 \x01(\t\x12$\n\x05peers\x18\x08 \x03(\x0b\x32\x15.voltha.Port.PeerPort\x12\x12\n\nrx_packets\x18\t \x01(\x06\x12\x10\n\x08rx_bytes\x18\n \x01(\x06\x12\x11\n\trx_errors\x18\x0b \x01(\x06\x12\x12\n\ntx_packets\x18\x0c \x01(\x06\x12\x10\n\x08tx_bytes\x18\r \x01(\x06\x12\x11\n\ttx_errors\x18\x0e \x01(\x06\x12\'\n\x08ofp_port\x18\x0f \x01(\x0b\x32\x15.openflow_13.ofp_port\x1a.\n\x08PeerPort\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0f\n\x07port_no\x18\x02 \x01(\r\"s\n\x08PortType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x10\n\x0c\x45THERNET_NNI\x10\x01\x12\x10\n\x0c\x45THERNET_UNI\x10\x02\x12\x0b\n\x07PON_OLT\x10\x03\x12\x0b\n\x07PON_ONU\x10\x04\x12\r\n\tVENET_OLT\x10\x05\x12\r\n\tVENET_ONU\x10\x06\"$\n\x05Ports\x12\x1b\n\x05items\x18\x01 \x03(\x0b\x32\x0c.voltha.Port\"\x9a\x08\n\x06\x44\x65vice\x12\x11\n\x02id\x18\x01 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x13\n\x04type\x18\x02 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x13\n\x04root\x18\x03 \x01(\x08\x42\x05\xe8\xf6\xcd\x1d\x01\x12\x18\n\tparent_id\x18\x04 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x1d\n\x0eparent_port_no\x18\x14 \x01(\rB\x05\xe8\xf6\xcd\x1d\x01\x12\x15\n\x06vendor\x18\x05 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x14\n\x05model\x18\x06 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x1f\n\x10hardware_version\x18\x07 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x1f\n\x10\x66irmware_version\x18\x08 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12%\n\x06images\x18\t \x01(\x0b\x32\x0e.voltha.ImagesB\x05\xe8\xf6\xcd\x1d\x01\x12\x1c\n\rserial_number\x18\n \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x18\n\tvendor_id\x18\x18 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x16\n\x07\x61\x64\x61pter\x18\x0b \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x0c\n\x04vlan\x18\x0c \x01(\r\x12\x13\n\x0bmac_address\x18\r \x01(\t\x12\x16\n\x0cipv4_address\x18\x0e \x01(\tH\x00\x12\x16\n\x0cipv6_address\x18\x0f \x01(\tH\x00\x12\x17\n\rhost_and_port\x18\x15 \x01(\tH\x00\x12\x12\n\nextra_args\x18\x17 \x01(\t\x12\x32\n\rproxy_address\x18\x13 \x01(\x0b\x32\x1b.voltha.Device.ProxyAddress\x12-\n\x0b\x61\x64min_state\x18\x10 \x01(\x0e\x32\x18.common.AdminState.Types\x12\x34\n\x0boper_status\x18\x11 \x01(\x0e\x32\x18.common.OperStatus.TypesB\x05\xe8\xf6\xcd\x1d\x01\x12\x15\n\x06reason\x18\x16 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12:\n\x0e\x63onnect_status\x18\x12 \x01(\x0e\x32\x1b.common.ConnectStatus.TypesB\x05\xe8\xf6\xcd\x1d\x01\x12$\n\x06\x63ustom\x18@ \x01(\x0b\x32\x14.google.protobuf.Any\x12-\n\npm_configs\x18\x83\x01 \x01(\x0b\x32\x11.voltha.PmConfigsB\x05\xe2\xf6\xcd\x1d\x00\x12<\n\x0fimage_downloads\x18\x85\x01 \x03(\x0b\x32\x15.voltha.ImageDownloadB\x0b\xe2\xf6\xcd\x1d\x06\n\x04name\x1a\xa9\x01\n\x0cProxyAddress\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x02 \x01(\t\x12\x12\n\nchannel_id\x18\x03 \x01(\r\x12\x18\n\x10\x63hannel_group_id\x18\x04 \x01(\r\x12\x1b\n\x13\x63hannel_termination\x18\x05 \x01(\t\x12\x0e\n\x06onu_id\x18\x06 \x01(\r\x12\x16\n\x0eonu_session_id\x18\x07 \x01(\rB\t\n\x07\x61\x64\x64ress\"(\n\x07\x44\x65vices\x12\x1d\n\x05items\x18\x01 \x03(\x0b\x32\x0e.voltha.Device\"\xb6\x02\n\x14SimulateAlarmRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tindicator\x18\x02 \x01(\t\x12\x0f\n\x07intf_id\x18\x03 \x01(\t\x12\x16\n\x0eport_type_name\x18\x04 \x01(\t\x12\x15\n\ronu_device_id\x18\x05 \x01(\t\x12\x1e\n\x16inverse_bit_error_rate\x18\x06 \x01(\x05\x12\r\n\x05\x64rift\x18\x07 \x01(\x05\x12\x0f\n\x07new_eqd\x18\x08 \x01(\x05\x12\x19\n\x11onu_serial_number\x18\t \x01(\t\x12=\n\toperation\x18\n \x01(\x0e\x32*.voltha.SimulateAlarmRequest.OperationType\"%\n\rOperationType\x12\t\n\x05RAISE\x10\x00\x12\t\n\x05\x43LEAR\x10\x01\x42S\n\x13org.opencord.volthaB\x0cVolthaDeviceZ.github.com/opencord/voltha-protos/v4/go/volthab\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_meta__pb2.DESCRIPTOR,voltha__protos_dot_openflow__13__pb2.DESCRIPTOR,])



_PMCONFIG_PMTYPE = _descriptor.EnumDescriptor(
  name='PmType',
  full_name='voltha.PmConfig.PmType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COUNTER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAUGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTEXT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=509,
  serialized_end=565,
)
_sym_db.RegisterEnumDescriptor(_PMCONFIG_PMTYPE)

_IMAGEDOWNLOAD_IMAGEDOWNLOADSTATE = _descriptor.EnumDescriptor(
  name='ImageDownloadState',
  full_name='voltha.ImageDownload.ImageDownloadState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOWNLOAD_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWNLOAD_SUCCEEDED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWNLOAD_REQUESTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWNLOAD_STARTED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWNLOAD_FAILED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWNLOAD_UNSUPPORTED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWNLOAD_CANCELLED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1449,
  serialized_end=1632,
)
_sym_db.RegisterEnumDescriptor(_IMAGEDOWNLOAD_IMAGEDOWNLOADSTATE)

_IMAGEDOWNLOAD_IMAGEDOWNLOADFAILUREREASON = _descriptor.EnumDescriptor(
  name='ImageDownloadFailureReason',
  full_name='voltha.ImageDownload.ImageDownloadFailureReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_ERROR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_URL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_BUSY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INSUFFICIENT_SPACE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ERROR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1635,
  serialized_end=1769,
)
_sym_db.RegisterEnumDescriptor(_IMAGEDOWNLOAD_IMAGEDOWNLOADFAILUREREASON)

_IMAGEDOWNLOAD_IMAGEACTIVATESTATE = _descriptor.EnumDescriptor(
  name='ImageActivateState',
  full_name='voltha.ImageDownload.ImageActivateState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IMAGE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_INACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_ACTIVATING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_ACTIVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_REVERTING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_REVERTED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1772,
  serialized_end=1912,
)
_sym_db.RegisterEnumDescriptor(_IMAGEDOWNLOAD_IMAGEACTIVATESTATE)

_PORT_PORTTYPE = _descriptor.EnumDescriptor(
  name='PortType',
  full_name='voltha.Port.PortType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ETHERNET_NNI', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ETHERNET_UNI', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PON_OLT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PON_ONU', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VENET_OLT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VENET_ONU', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2402,
  serialized_end=2517,
)
_sym_db.RegisterEnumDescriptor(_PORT_PORTTYPE)

_SIMULATEALARMREQUEST_OPERATIONTYPE = _descriptor.EnumDescriptor(
  name='OperationType',
  full_name='voltha.SimulateAlarmRequest.OperationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RAISE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEAR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3926,
  serialized_end=3963,
)
_sym_db.RegisterEnumDescriptor(_SIMULATEALARMREQUEST_OPERATIONTYPE)


_DEVICETYPE = _descriptor.Descriptor(
  name='DeviceType',
  full_name='voltha.DeviceType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.DeviceType.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor_id', full_name='voltha.DeviceType.vendor_id', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor_ids', full_name='voltha.DeviceType.vendor_ids', index=2,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adapter', full_name='voltha.DeviceType.adapter', index=3,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepts_bulk_flow_update', full_name='voltha.DeviceType.accepts_bulk_flow_update', index=4,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepts_add_remove_flow_updates', full_name='voltha.DeviceType.accepts_add_remove_flow_updates', index=5,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accepts_direct_logical_flows_update', full_name='voltha.DeviceType.accepts_direct_logical_flows_update', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=353,
)


_DEVICETYPES = _descriptor.Descriptor(
  name='DeviceTypes',
  full_name='voltha.DeviceTypes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='voltha.DeviceTypes.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=403,
)


_PMCONFIG = _descriptor.Descriptor(
  name='PmConfig',
  full_name='voltha.PmConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='voltha.PmConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.PmConfig.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='voltha.PmConfig.enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_freq', full_name='voltha.PmConfig.sample_freq', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PMCONFIG_PMTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=406,
  serialized_end=565,
)


_PMGROUPCONFIG = _descriptor.Descriptor(
  name='PmGroupConfig',
  full_name='voltha.PmGroupConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_name', full_name='voltha.PmGroupConfig.group_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_freq', full_name='voltha.PmGroupConfig.group_freq', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='voltha.PmGroupConfig.enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='voltha.PmGroupConfig.metrics', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=674,
)


_PMCONFIGS = _descriptor.Descriptor(
  name='PmConfigs',
  full_name='voltha.PmConfigs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.PmConfigs.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_freq', full_name='voltha.PmConfigs.default_freq', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grouped', full_name='voltha.PmConfigs.grouped', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='freq_override', full_name='voltha.PmConfigs.freq_override', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='voltha.PmConfigs.groups', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='voltha.PmConfigs.metrics', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_skew', full_name='voltha.PmConfigs.max_skew', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=677,
  serialized_end=868,
)


_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='voltha.Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='voltha.Image.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='voltha.Image.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash', full_name='voltha.Image.hash', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='install_datetime', full_name='voltha.Image.install_datetime', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_active', full_name='voltha.Image.is_active', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_committed', full_name='voltha.Image.is_committed', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_valid', full_name='voltha.Image.is_valid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=871,
  serialized_end=1008,
)


_IMAGES = _descriptor.Descriptor(
  name='Images',
  full_name='voltha.Images',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='voltha.Images.image', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1010,
  serialized_end=1048,
)


_IMAGEDOWNLOAD = _descriptor.Descriptor(
  name='ImageDownload',
  full_name='voltha.ImageDownload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.ImageDownload.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='voltha.ImageDownload.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='voltha.ImageDownload.url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crc', full_name='voltha.ImageDownload.crc', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='download_state', full_name='voltha.ImageDownload.download_state', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_version', full_name='voltha.ImageDownload.image_version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downloaded_bytes', full_name='voltha.ImageDownload.downloaded_bytes', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='voltha.ImageDownload.reason', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_info', full_name='voltha.ImageDownload.additional_info', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='save_config', full_name='voltha.ImageDownload.save_config', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_dir', full_name='voltha.ImageDownload.local_dir', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_state', full_name='voltha.ImageDownload.image_state', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='voltha.ImageDownload.file_size', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IMAGEDOWNLOAD_IMAGEDOWNLOADSTATE,
    _IMAGEDOWNLOAD_IMAGEDOWNLOADFAILUREREASON,
    _IMAGEDOWNLOAD_IMAGEACTIVATESTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1051,
  serialized_end=1912,
)


_IMAGEDOWNLOADS = _descriptor.Descriptor(
  name='ImageDownloads',
  full_name='voltha.ImageDownloads',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='voltha.ImageDownloads.items', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1914,
  serialized_end=1968,
)


_PORT_PEERPORT = _descriptor.Descriptor(
  name='PeerPort',
  full_name='voltha.Port.PeerPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.Port.PeerPort.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='voltha.Port.PeerPort.port_no', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2354,
  serialized_end=2400,
)

_PORT = _descriptor.Descriptor(
  name='Port',
  full_name='voltha.Port',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_no', full_name='voltha.Port.port_no', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='voltha.Port.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.Port.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin_state', full_name='voltha.Port.admin_state', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oper_status', full_name='voltha.Port.oper_status', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.Port.device_id', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peers', full_name='voltha.Port.peers', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_packets', full_name='voltha.Port.rx_packets', index=7,
      number=9, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_bytes', full_name='voltha.Port.rx_bytes', index=8,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_errors', full_name='voltha.Port.rx_errors', index=9,
      number=11, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_packets', full_name='voltha.Port.tx_packets', index=10,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_bytes', full_name='voltha.Port.tx_bytes', index=11,
      number=13, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_errors', full_name='voltha.Port.tx_errors', index=12,
      number=14, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ofp_port', full_name='voltha.Port.ofp_port', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PORT_PEERPORT, ],
  enum_types=[
    _PORT_PORTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1971,
  serialized_end=2517,
)


_PORTS = _descriptor.Descriptor(
  name='Ports',
  full_name='voltha.Ports',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='voltha.Ports.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2519,
  serialized_end=2555,
)


_DEVICE_PROXYADDRESS = _descriptor.Descriptor(
  name='ProxyAddress',
  full_name='voltha.Device.ProxyAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.Device.ProxyAddress.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_type', full_name='voltha.Device.ProxyAddress.device_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='voltha.Device.ProxyAddress.channel_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_group_id', full_name='voltha.Device.ProxyAddress.channel_group_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_termination', full_name='voltha.Device.ProxyAddress.channel_termination', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='voltha.Device.ProxyAddress.onu_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_session_id', full_name='voltha.Device.ProxyAddress.onu_session_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3428,
  serialized_end=3597,
)

_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='voltha.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.Device.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.Device.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='root', full_name='voltha.Device.root', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='voltha.Device.parent_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_port_no', full_name='voltha.Device.parent_port_no', index=4,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='voltha.Device.vendor', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='voltha.Device.model', index=6,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hardware_version', full_name='voltha.Device.hardware_version', index=7,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firmware_version', full_name='voltha.Device.firmware_version', index=8,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='images', full_name='voltha.Device.images', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='voltha.Device.serial_number', index=10,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor_id', full_name='voltha.Device.vendor_id', index=11,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adapter', full_name='voltha.Device.adapter', index=12,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vlan', full_name='voltha.Device.vlan', index=13,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac_address', full_name='voltha.Device.mac_address', index=14,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_address', full_name='voltha.Device.ipv4_address', index=15,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv6_address', full_name='voltha.Device.ipv6_address', index=16,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_and_port', full_name='voltha.Device.host_and_port', index=17,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_args', full_name='voltha.Device.extra_args', index=18,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxy_address', full_name='voltha.Device.proxy_address', index=19,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin_state', full_name='voltha.Device.admin_state', index=20,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oper_status', full_name='voltha.Device.oper_status', index=21,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='voltha.Device.reason', index=22,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_status', full_name='voltha.Device.connect_status', index=23,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='voltha.Device.custom', index=24,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pm_configs', full_name='voltha.Device.pm_configs', index=25,
      number=131, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_downloads', full_name='voltha.Device.image_downloads', index=26,
      number=133, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\006\n\004name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DEVICE_PROXYADDRESS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address', full_name='voltha.Device.address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2558,
  serialized_end=3608,
)


_DEVICES = _descriptor.Descriptor(
  name='Devices',
  full_name='voltha.Devices',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='voltha.Devices.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3610,
  serialized_end=3650,
)


_SIMULATEALARMREQUEST = _descriptor.Descriptor(
  name='SimulateAlarmRequest',
  full_name='voltha.SimulateAlarmRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.SimulateAlarmRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indicator', full_name='voltha.SimulateAlarmRequest.indicator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='voltha.SimulateAlarmRequest.intf_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_type_name', full_name='voltha.SimulateAlarmRequest.port_type_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_device_id', full_name='voltha.SimulateAlarmRequest.onu_device_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inverse_bit_error_rate', full_name='voltha.SimulateAlarmRequest.inverse_bit_error_rate', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drift', full_name='voltha.SimulateAlarmRequest.drift', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_eqd', full_name='voltha.SimulateAlarmRequest.new_eqd', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_serial_number', full_name='voltha.SimulateAlarmRequest.onu_serial_number', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation', full_name='voltha.SimulateAlarmRequest.operation', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIMULATEALARMREQUEST_OPERATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3653,
  serialized_end=3963,
)

_DEVICETYPES.fields_by_name['items'].message_type = _DEVICETYPE
_PMCONFIG.fields_by_name['type'].enum_type = _PMCONFIG_PMTYPE
_PMCONFIG_PMTYPE.containing_type = _PMCONFIG
_PMGROUPCONFIG.fields_by_name['metrics'].message_type = _PMCONFIG
_PMCONFIGS.fields_by_name['groups'].message_type = _PMGROUPCONFIG
_PMCONFIGS.fields_by_name['metrics'].message_type = _PMCONFIG
_IMAGES.fields_by_name['image'].message_type = _IMAGE
_IMAGEDOWNLOAD.fields_by_name['download_state'].enum_type = _IMAGEDOWNLOAD_IMAGEDOWNLOADSTATE
_IMAGEDOWNLOAD.fields_by_name['reason'].enum_type = _IMAGEDOWNLOAD_IMAGEDOWNLOADFAILUREREASON
_IMAGEDOWNLOAD.fields_by_name['image_state'].enum_type = _IMAGEDOWNLOAD_IMAGEACTIVATESTATE
_IMAGEDOWNLOAD_IMAGEDOWNLOADSTATE.containing_type = _IMAGEDOWNLOAD
_IMAGEDOWNLOAD_IMAGEDOWNLOADFAILUREREASON.containing_type = _IMAGEDOWNLOAD
_IMAGEDOWNLOAD_IMAGEACTIVATESTATE.containing_type = _IMAGEDOWNLOAD
_IMAGEDOWNLOADS.fields_by_name['items'].message_type = _IMAGEDOWNLOAD
_PORT_PEERPORT.containing_type = _PORT
_PORT.fields_by_name['type'].enum_type = _PORT_PORTTYPE
_PORT.fields_by_name['admin_state'].enum_type = voltha__protos_dot_common__pb2._ADMINSTATE_TYPES
_PORT.fields_by_name['oper_status'].enum_type = voltha__protos_dot_common__pb2._OPERSTATUS_TYPES
_PORT.fields_by_name['peers'].message_type = _PORT_PEERPORT
_PORT.fields_by_name['ofp_port'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_PORT
_PORT_PORTTYPE.containing_type = _PORT
_PORTS.fields_by_name['items'].message_type = _PORT
_DEVICE_PROXYADDRESS.containing_type = _DEVICE
_DEVICE.fields_by_name['images'].message_type = _IMAGES
_DEVICE.fields_by_name['proxy_address'].message_type = _DEVICE_PROXYADDRESS
_DEVICE.fields_by_name['admin_state'].enum_type = voltha__protos_dot_common__pb2._ADMINSTATE_TYPES
_DEVICE.fields_by_name['oper_status'].enum_type = voltha__protos_dot_common__pb2._OPERSTATUS_TYPES
_DEVICE.fields_by_name['connect_status'].enum_type = voltha__protos_dot_common__pb2._CONNECTSTATUS_TYPES
_DEVICE.fields_by_name['custom'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_DEVICE.fields_by_name['pm_configs'].message_type = _PMCONFIGS
_DEVICE.fields_by_name['image_downloads'].message_type = _IMAGEDOWNLOAD
_DEVICE.oneofs_by_name['address'].fields.append(
  _DEVICE.fields_by_name['ipv4_address'])
_DEVICE.fields_by_name['ipv4_address'].containing_oneof = _DEVICE.oneofs_by_name['address']
_DEVICE.oneofs_by_name['address'].fields.append(
  _DEVICE.fields_by_name['ipv6_address'])
_DEVICE.fields_by_name['ipv6_address'].containing_oneof = _DEVICE.oneofs_by_name['address']
_DEVICE.oneofs_by_name['address'].fields.append(
  _DEVICE.fields_by_name['host_and_port'])
_DEVICE.fields_by_name['host_and_port'].containing_oneof = _DEVICE.oneofs_by_name['address']
_DEVICES.fields_by_name['items'].message_type = _DEVICE
_SIMULATEALARMREQUEST.fields_by_name['operation'].enum_type = _SIMULATEALARMREQUEST_OPERATIONTYPE
_SIMULATEALARMREQUEST_OPERATIONTYPE.containing_type = _SIMULATEALARMREQUEST
DESCRIPTOR.message_types_by_name['DeviceType'] = _DEVICETYPE
DESCRIPTOR.message_types_by_name['DeviceTypes'] = _DEVICETYPES
DESCRIPTOR.message_types_by_name['PmConfig'] = _PMCONFIG
DESCRIPTOR.message_types_by_name['PmGroupConfig'] = _PMGROUPCONFIG
DESCRIPTOR.message_types_by_name['PmConfigs'] = _PMCONFIGS
DESCRIPTOR.message_types_by_name['Image'] = _IMAGE
DESCRIPTOR.message_types_by_name['Images'] = _IMAGES
DESCRIPTOR.message_types_by_name['ImageDownload'] = _IMAGEDOWNLOAD
DESCRIPTOR.message_types_by_name['ImageDownloads'] = _IMAGEDOWNLOADS
DESCRIPTOR.message_types_by_name['Port'] = _PORT
DESCRIPTOR.message_types_by_name['Ports'] = _PORTS
DESCRIPTOR.message_types_by_name['Device'] = _DEVICE
DESCRIPTOR.message_types_by_name['Devices'] = _DEVICES
DESCRIPTOR.message_types_by_name['SimulateAlarmRequest'] = _SIMULATEALARMREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DeviceType = _reflection.GeneratedProtocolMessageType('DeviceType', (_message.Message,), {
  'DESCRIPTOR' : _DEVICETYPE,
  '__module__' : 'voltha_protos.device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.DeviceType)
  })
_sym_db.RegisterMessage(DeviceType)

DeviceTypes = _reflection.GeneratedProtocolMessageType('DeviceTypes', (_message.Message,), {
  'DESCRIPTOR' : _DEVICETYPES,
  '__module__' : 'voltha_protos.device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.DeviceTypes)
  })
_sym_db.RegisterMessage(DeviceTypes)

PmConfig = _reflection.GeneratedProtocolMessageType('PmConfig', (_message.Message,), {
  'DESCRIPTOR' : _PMCONFIG,
  '__module__' : 'voltha_protos.device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PmConfig)
  })
_sym_db.RegisterMessage(PmConfig)

PmGroupConfig = _reflection.GeneratedProtocolMessageType('PmGroupConfig', (_message.Message,), {
  'DESCRIPTOR' : _PMGROUPCONFIG,
  '__module__' : 'voltha_protos.device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PmGroupConfig)
  })
_sym_db.RegisterMessage(PmGroupConfig)

PmConfigs = _reflection.GeneratedProtocolMessageType('PmConfigs', (_message.Message,), {
  'DESCRIPTOR' : _PMCONFIGS,
  '__module__' : 'voltha_protos.device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PmConfigs)
  })
_sym_db.RegisterMessage(PmConfigs)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), {
  'DESCRIPTOR' : _IMAGE,
  '__module__' : 'voltha_protos.device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Image)
  })
_sym_db.RegisterMessage(Image)

Images = _reflection.GeneratedProtocolMessageType('Images', (_message.Message,), {
  'DESCRIPTOR' : _IMAGES,
  '__module__' : 'voltha_protos.device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Images)
  })
_sym_db.RegisterMessage(Images)

ImageDownload = _reflection.GeneratedProtocolMessageType('ImageDownload', (_message.Message,), {
  'DESCRIPTOR' : _IMAGEDOWNLOAD,
  '__module__' : 'voltha_protos.device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.ImageDownload)
  })
_sym_db.RegisterMessage(ImageDownload)

ImageDownloads = _reflection.GeneratedProtocolMessageType('ImageDownloads', (_message.Message,), {
  'DESCRIPTOR' : _IMAGEDOWNLOADS,
  '__module__' : 'voltha_protos.device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.ImageDownloads)
  })
_sym_db.RegisterMessage(ImageDownloads)

Port = _reflection.GeneratedProtocolMessageType('Port', (_message.Message,), {

  'PeerPort' : _reflection.GeneratedProtocolMessageType('PeerPort', (_message.Message,), {
    'DESCRIPTOR' : _PORT_PEERPORT,
    '__module__' : 'voltha_protos.device_pb2'
    # @@protoc_insertion_point(class_scope:voltha.Port.PeerPort)
    })
  ,
  'DESCRIPTOR' : _PORT,
  '__module__' : 'voltha_protos.device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Port)
  })
_sym_db.RegisterMessage(Port)
_sym_db.RegisterMessage(Port.PeerPort)

Ports = _reflection.GeneratedProtocolMessageType('Ports', (_message.Message,), {
  'DESCRIPTOR' : _PORTS,
  '__module__' : 'voltha_protos.device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Ports)
  })
_sym_db.RegisterMessage(Ports)

Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {

  'ProxyAddress' : _reflection.GeneratedProtocolMessageType('ProxyAddress', (_message.Message,), {
    'DESCRIPTOR' : _DEVICE_PROXYADDRESS,
    '__module__' : 'voltha_protos.device_pb2'
    # @@protoc_insertion_point(class_scope:voltha.Device.ProxyAddress)
    })
  ,
  'DESCRIPTOR' : _DEVICE,
  '__module__' : 'voltha_protos.device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Device)
  })
_sym_db.RegisterMessage(Device)
_sym_db.RegisterMessage(Device.ProxyAddress)

Devices = _reflection.GeneratedProtocolMessageType('Devices', (_message.Message,), {
  'DESCRIPTOR' : _DEVICES,
  '__module__' : 'voltha_protos.device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Devices)
  })
_sym_db.RegisterMessage(Devices)

SimulateAlarmRequest = _reflection.GeneratedProtocolMessageType('SimulateAlarmRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATEALARMREQUEST,
  '__module__' : 'voltha_protos.device_pb2'
  # @@protoc_insertion_point(class_scope:voltha.SimulateAlarmRequest)
  })
_sym_db.RegisterMessage(SimulateAlarmRequest)


DESCRIPTOR._options = None
_PMCONFIGS.fields_by_name['grouped']._options = None
_PMCONFIGS.fields_by_name['freq_override']._options = None
_DEVICE.fields_by_name['id']._options = None
_DEVICE.fields_by_name['type']._options = None
_DEVICE.fields_by_name['root']._options = None
_DEVICE.fields_by_name['parent_id']._options = None
_DEVICE.fields_by_name['parent_port_no']._options = None
_DEVICE.fields_by_name['vendor']._options = None
_DEVICE.fields_by_name['model']._options = None
_DEVICE.fields_by_name['hardware_version']._options = None
_DEVICE.fields_by_name['firmware_version']._options = None
_DEVICE.fields_by_name['images']._options = None
_DEVICE.fields_by_name['serial_number']._options = None
_DEVICE.fields_by_name['vendor_id']._options = None
_DEVICE.fields_by_name['adapter']._options = None
_DEVICE.fields_by_name['oper_status']._options = None
_DEVICE.fields_by_name['reason']._options = None
_DEVICE.fields_by_name['connect_status']._options = None
_DEVICE.fields_by_name['pm_configs']._options = None
_DEVICE.fields_by_name['image_downloads']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/omci_alarm_db.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import meta_pb2 as voltha__protos_dot_meta__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/omci_alarm_db.proto',
  package='omci',
  syntax='proto3',
  serialized_options=b'\n\030org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v4/go/omci',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!voltha_protos/omci_alarm_db.proto\x12\x04omci\x1a\x18voltha_protos/meta.proto\"8\n\x12\x41larmAttributeData\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\r\n\x05value\x18\x02 \x01(\t\"\x8d\x01\n\x11\x41larmInstanceData\x12\x1a\n\x0binstance_id\x18\x01 \x01(\rB\x05\xe8\xf6\xcd\x1d\x01\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\x10\n\x08modified\x18\x03 \x01(\t\x12\x39\n\nattributes\x18\x04 \x03(\x0b\x32\x18.omci.AlarmAttributeDataB\x0b\xe2\xf6\xcd\x1d\x06\n\x04name\"i\n\x0e\x41larmClassData\x12\x17\n\x08\x63lass_id\x18\x01 \x01(\rB\x05\xe8\xf6\xcd\x1d\x01\x12>\n\tinstances\x18\x02 \x03(\x0b\x32\x17.omci.AlarmInstanceDataB\x12\xe2\xf6\xcd\x1d\r\n\x0binstance_id\"B\n\x12\x41larmManagedEntity\x12\x17\n\x08\x63lass_id\x18\x01 \x01(\rB\x05\xe8\xf6\xcd\x1d\x01\x12\x13\n\x04name\x18\x02 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\"/\n\x10\x41larmMessageType\x12\x1b\n\x0cmessage_type\x18\x01 \x01(\rB\x05\xe8\xf6\xcd\x1d\x01\"\x9d\x02\n\x0f\x41larmDeviceData\x12\x18\n\tdevice_id\x18\x01 \x01(\tB\x05\xe8\xf6\xcd\x1d\x01\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\x1b\n\x13last_alarm_sequence\x18\x03 \x01(\r\x12\x16\n\x0elast_sync_time\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\r\x12\x36\n\x07\x63lasses\x18\x06 \x03(\x0b\x32\x14.omci.AlarmClassDataB\x0f\xe2\xf6\xcd\x1d\n\n\x08\x63lass_id\x12\x32\n\x10managed_entities\x18\x07 \x03(\x0b\x32\x18.omci.AlarmManagedEntity\x12-\n\rmessage_types\x18\x08 \x03(\x0b\x32\x16.omci.AlarmMessageType\"?\n\x16\x41larmOpenOmciEventType\"%\n\x11OpenOmciEventType\x12\x10\n\x0cstate_change\x10\x00\"`\n\x12\x41larmOpenOmciEvent\x12<\n\x04type\x18\x01 \x01(\x0e\x32..omci.AlarmOpenOmciEventType.OpenOmciEventType\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\tBH\n\x18org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v4/go/omcib\x06proto3'
  ,
  dependencies=[voltha__protos_dot_meta__pb2.DESCRIPTOR,])



_ALARMOPENOMCIEVENTTYPE_OPENOMCIEVENTTYPE = _descriptor.EnumDescriptor(
  name='OpenOmciEventType',
  full_name='omci.AlarmOpenOmciEventType.OpenOmciEventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='state_change', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=809,
  serialized_end=846,
)
_sym_db.RegisterEnumDescriptor(_ALARMOPENOMCIEVENTTYPE_OPENOMCIEVENTTYPE)


_ALARMATTRIBUTEDATA = _descriptor.Descriptor(
  name='AlarmAttributeData',
  full_name='omci.AlarmAttributeData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='omci.AlarmAttributeData.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='omci.AlarmAttributeData.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=125,
)


_ALARMINSTANCEDATA = _descriptor.Descriptor(
  name='AlarmInstanceData',
  full_name='omci.AlarmInstanceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='omci.AlarmInstanceData.instance_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='omci.AlarmInstanceData.created', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified', full_name='omci.AlarmInstanceData.modified', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='omci.AlarmInstanceData.attributes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\006\n\004name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=269,
)


_ALARMCLASSDATA = _descriptor.Descriptor(
  name='AlarmClassData',
  full_name='omci.AlarmClassData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_id', full_name='omci.AlarmClassData.class_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instances', full_name='omci.AlarmClassData.instances', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\r\n\013instance_id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=376,
)


_ALARMMANAGEDENTITY = _descriptor.Descriptor(
  name='AlarmManagedEntity',
  full_name='omci.AlarmManagedEntity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_id', full_name='omci.AlarmManagedEntity.class_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='omci.AlarmManagedEntity.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=444,
)


_ALARMMESSAGETYPE = _descriptor.Descriptor(
  name='AlarmMessageType',
  full_name='omci.AlarmMessageType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_type', full_name='omci.AlarmMessageType.message_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=493,
)


_ALARMDEVICEDATA = _descriptor.Descriptor(
  name='AlarmDeviceData',
  full_name='omci.AlarmDeviceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='omci.AlarmDeviceData.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\366\315\035\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='omci.AlarmDeviceData.created', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_alarm_sequence', full_name='omci.AlarmDeviceData.last_alarm_sequence', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_sync_time', full_name='omci.AlarmDeviceData.last_sync_time', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='omci.AlarmDeviceData.version', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classes', full_name='omci.AlarmDeviceData.classes', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\366\315\035\n\n\010class_id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='managed_entities', full_name='omci.AlarmDeviceData.managed_entities', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_types', full_name='omci.AlarmDeviceData.message_types', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=496,
  serialized_end=781,
)


_ALARMOPENOMCIEVENTTYPE = _descriptor.Descriptor(
  name='AlarmOpenOmciEventType',
  full_name='omci.AlarmOpenOmciEventType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALARMOPENOMCIEVENTTYPE_OPENOMCIEVENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=783,
  serialized_end=846,
)


_ALARMOPENOMCIEVENT = _descriptor.Descriptor(
  name='AlarmOpenOmciEvent',
  full_name='omci.AlarmOpenOmciEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='omci.AlarmOpenOmciEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='omci.AlarmOpenOmciEvent.data', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=848,
  serialized_end=944,
)

_ALARMINSTANCEDATA.fields_by_name['attributes'].message_type = _ALARMATTRIBUTEDATA
_ALARMCLASSDATA.fields_by_name['instances'].message_type = _ALARMINSTANCEDATA
_ALARMDEVICEDATA.fields_by_name['classes'].message_type = _ALARMCLASSDATA
_ALARMDEVICEDATA.fields_by_name['managed_entities'].message_type = _ALARMMANAGEDENTITY
_ALARMDEVICEDATA.fields_by_name['message_types'].message_type = _ALARMMESSAGETYPE
_ALARMOPENOMCIEVENTTYPE_OPENOMCIEVENTTYPE.containing_type = _ALARMOPENOMCIEVENTTYPE
_ALARMOPENOMCIEVENT.fields_by_name['type'].enum_type = _ALARMOPENOMCIEVENTTYPE_OPENOMCIEVENTTYPE
DESCRIPTOR.message_types_by_name['AlarmAttributeData'] = _ALARMATTRIBUTEDATA
DESCRIPTOR.message_types_by_name['AlarmInstanceData'] = _ALARMINSTANCEDATA
DESCRIPTOR.message_types_by_name['AlarmClassData'] = _ALARMCLASSDATA
DESCRIPTOR.message_types_by_name['AlarmManagedEntity'] = _ALARMMANAGEDENTITY
DESCRIPTOR.message_types_by_name['AlarmMessageType'] = _ALARMMESSAGETYPE
DESCRIPTOR.message_types_by_name['AlarmDeviceData'] = _ALARMDEVICEDATA
DESCRIPTOR.message_types_by_name['AlarmOpenOmciEventType'] = _ALARMOPENOMCIEVENTTYPE
DESCRIPTOR.message_types_by_name['AlarmOpenOmciEvent'] = _ALARMOPENOMCIEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AlarmAttributeData = _reflection.GeneratedProtocolMessageType('AlarmAttributeData', (_message.Message,), {
  'DESCRIPTOR' : _ALARMATTRIBUTEDATA,
  '__module__' : 'voltha_protos.omci_alarm_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.AlarmAttributeData)
  })
_sym_db.RegisterMessage(AlarmAttributeData)

AlarmInstanceData = _reflection.GeneratedProtocolMessageType('AlarmInstanceData', (_message.Message,), {
  'DESCRIPTOR' : _ALARMINSTANCEDATA,
  '__module__' : 'voltha_protos.omci_alarm_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.AlarmInstanceData)
  })
_sym_db.RegisterMessage(AlarmInstanceData)

AlarmClassData = _reflection.GeneratedProtocolMessageType('AlarmClassData', (_message.Message,), {
  'DESCRIPTOR' : _ALARMCLASSDATA,
  '__module__' : 'voltha_protos.omci_alarm_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.AlarmClassData)
  })
_sym_db.RegisterMessage(AlarmClassData)

AlarmManagedEntity = _reflection.GeneratedProtocolMessageType('AlarmManagedEntity', (_message.Message,), {
  'DESCRIPTOR' : _ALARMMANAGEDENTITY,
  '__module__' : 'voltha_protos.omci_alarm_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.AlarmManagedEntity)
  })
_sym_db.RegisterMessage(AlarmManagedEntity)

AlarmMessageType = _reflection.GeneratedProtocolMessageType('AlarmMessageType', (_message.Message,), {
  'DESCRIPTOR' : _ALARMMESSAGETYPE,
  '__module__' : 'voltha_protos.omci_alarm_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.AlarmMessageType)
  })
_sym_db.RegisterMessage(AlarmMessageType)

AlarmDeviceData = _reflection.GeneratedProtocolMessageType('AlarmDeviceData', (_message.Message,), {
  'DESCRIPTOR' : _ALARMDEVICEDATA,
  '__module__' : 'voltha_protos.omci_alarm_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.AlarmDeviceData)
  })
_sym_db.RegisterMessage(AlarmDeviceData)

AlarmOpenOmciEventType = _reflection.GeneratedProtocolMessageType('AlarmOpenOmciEventType', (_message.Message,), {
  'DESCRIPTOR' : _ALARMOPENOMCIEVENTTYPE,
  '__module__' : 'voltha_protos.omci_alarm_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.AlarmOpenOmciEventType)
  })
_sym_db.RegisterMessage(AlarmOpenOmciEventType)

AlarmOpenOmciEvent = _reflection.GeneratedProtocolMessageType('AlarmOpenOmciEvent', (_message.Message,), {
  'DESCRIPTOR' : _ALARMOPENOMCIEVENT,
  '__module__' : 'voltha_protos.omci_alarm_db_pb2'
  # @@protoc_insertion_point(class_scope:omci.AlarmOpenOmciEvent)
  })
_sym_db.RegisterMessage(AlarmOpenOmciEvent)


DESCRIPTOR._options = None
_ALARMATTRIBUTEDATA.fields_by_name['name']._options = None
_ALARMINSTANCEDATA.fields_by_name['instance_id']._options = None
_ALARMINSTANCEDATA.fields_by_name['attributes']._options = None
_ALARMCLASSDATA.fields_by_name['class_id']._options = None
_ALARMCLASSDATA.fields_by_name['instances']._options = None
_ALARMMANAGEDENTITY.fields_by_name['class_id']._options = None
_ALARMMANAGEDENTITY.fields_by_name['name']._options = None
_ALARMMESSAGETYPE.fields_by_name['message_type']._options = None
_ALARMDEVICEDATA.fields_by_name['device_id']._options = None
_ALARMDEVICEDATA.fields_by_name['classes']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/ext_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/ext_config.proto',
  package='config',
  syntax='proto3',
  serialized_options=b'\n\023org.opencord.volthaZ2github.com/opencord/voltha-protos/v4/go/ext/config',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1evoltha_protos/ext_config.proto\x12\x06\x63onfig\"S\n\x0b\x41larmConfig\x12:\n\x18onu_itu_pon_alarm_config\x18\x01 \x01(\x0b\x32\x16.config.OnuItuPonAlarmH\x00\x42\x08\n\x06\x63onfig\"\xb9\x07\n\x0eOnuItuPonAlarm\x12\x0e\n\x06pon_ni\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x30\n\x08\x61larm_id\x18\x03 \x01(\x0e\x32\x1e.config.OnuItuPonAlarm.AlarmID\x12Q\n\x19\x61larm_reporting_condition\x18\x04 \x01(\x0e\x32..config.OnuItuPonAlarm.AlarmReportingCondition\x12K\n\x15rate_threshold_config\x18\x05 \x01(\x0b\x32*.config.OnuItuPonAlarm.RateThresholdConfigH\x00\x12\x43\n\x11rate_range_config\x18\x06 \x01(\x0b\x32&.config.OnuItuPonAlarm.RateRangeConfigH\x00\x12M\n\x16value_threshold_config\x18\x07 \x01(\x0b\x32+.config.OnuItuPonAlarm.ValueThresholdConfigH\x00\x1a=\n\x08SoakTime\x12\x18\n\x10\x61\x63tive_soak_time\x18\x01 \x01(\x07\x12\x17\n\x0f\x63lear_soak_time\x18\x02 \x01(\x07\x1a\x88\x01\n\x13RateThresholdConfig\x12\x1d\n\x15rate_threshold_rising\x18\x01 \x01(\x06\x12\x1e\n\x16rate_threshold_falling\x18\x02 \x01(\x06\x12\x32\n\tsoak_time\x18\x03 \x01(\x0b\x32\x1f.config.OnuItuPonAlarm.SoakTime\x1ay\n\x0fRateRangeConfig\x12\x18\n\x10rate_range_lower\x18\x01 \x01(\x06\x12\x18\n\x10rate_range_upper\x18\x02 \x01(\x06\x12\x32\n\tsoak_time\x18\x03 \x01(\x0b\x32\x1f.config.OnuItuPonAlarm.SoakTime\x1a\x63\n\x14ValueThresholdConfig\x12\x17\n\x0fthreshold_limit\x18\x01 \x01(\x06\x12\x32\n\tsoak_time\x18\x02 \x01(\x0b\x32\x1f.config.OnuItuPonAlarm.SoakTime\"\x19\n\x07\x41larmID\x12\x0e\n\nRDI_ERRORS\x10\x00\"R\n\x17\x41larmReportingCondition\x12\x12\n\x0eRATE_THRESHOLD\x10\x00\x12\x0e\n\nRATE_RANGE\x10\x01\x12\x13\n\x0fVALUE_THRESHOLD\x10\x02\x42\x08\n\x06\x63onfigBI\n\x13org.opencord.volthaZ2github.com/opencord/voltha-protos/v4/go/ext/configb\x06proto3'
)



_ONUITUPONALARM_ALARMID = _descriptor.EnumDescriptor(
  name='AlarmID',
  full_name='config.OnuItuPonAlarm.AlarmID',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RDI_ERRORS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=962,
  serialized_end=987,
)
_sym_db.RegisterEnumDescriptor(_ONUITUPONALARM_ALARMID)

_ONUITUPONALARM_ALARMREPORTINGCONDITION = _descriptor.EnumDescriptor(
  name='AlarmReportingCondition',
  full_name='config.OnuItuPonAlarm.AlarmReportingCondition',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RATE_THRESHOLD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RATE_RANGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VALUE_THRESHOLD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=989,
  serialized_end=1071,
)
_sym_db.RegisterEnumDescriptor(_ONUITUPONALARM_ALARMREPORTINGCONDITION)


_ALARMCONFIG = _descriptor.Descriptor(
  name='AlarmConfig',
  full_name='config.AlarmConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='onu_itu_pon_alarm_config', full_name='config.AlarmConfig.onu_itu_pon_alarm_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config', full_name='config.AlarmConfig.config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=42,
  serialized_end=125,
)


_ONUITUPONALARM_SOAKTIME = _descriptor.Descriptor(
  name='SoakTime',
  full_name='config.OnuItuPonAlarm.SoakTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='active_soak_time', full_name='config.OnuItuPonAlarm.SoakTime.active_soak_time', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_soak_time', full_name='config.OnuItuPonAlarm.SoakTime.clear_soak_time', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=597,
)

_ONUITUPONALARM_RATETHRESHOLDCONFIG = _descriptor.Descriptor(
  name='RateThresholdConfig',
  full_name='config.OnuItuPonAlarm.RateThresholdConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rate_threshold_rising', full_name='config.OnuItuPonAlarm.RateThresholdConfig.rate_threshold_rising', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_threshold_falling', full_name='config.OnuItuPonAlarm.RateThresholdConfig.rate_threshold_falling', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='soak_time', full_name='config.OnuItuPonAlarm.RateThresholdConfig.soak_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=600,
  serialized_end=736,
)

_ONUITUPONALARM_RATERANGECONFIG = _descriptor.Descriptor(
  name='RateRangeConfig',
  full_name='config.OnuItuPonAlarm.RateRangeConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rate_range_lower', full_name='config.OnuItuPonAlarm.RateRangeConfig.rate_range_lower', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_range_upper', full_name='config.OnuItuPonAlarm.RateRangeConfig.rate_range_upper', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='soak_time', full_name='config.OnuItuPonAlarm.RateRangeConfig.soak_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=738,
  serialized_end=859,
)

_ONUITUPONALARM_VALUETHRESHOLDCONFIG = _descriptor.Descriptor(
  name='ValueThresholdConfig',
  full_name='config.OnuItuPonAlarm.ValueThresholdConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='threshold_limit', full_name='config.OnuItuPonAlarm.ValueThresholdConfig.threshold_limit', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='soak_time', full_name='config.OnuItuPonAlarm.ValueThresholdConfig.soak_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=861,
  serialized_end=960,
)

_ONUITUPONALARM = _descriptor.Descriptor(
  name='OnuItuPonAlarm',
  full_name='config.OnuItuPonAlarm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pon_ni', full_name='config.OnuItuPonAlarm.pon_ni', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='config.OnuItuPonAlarm.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alarm_id', full_name='config.OnuItuPonAlarm.alarm_id', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alarm_reporting_condition', full_name='config.OnuItuPonAlarm.alarm_reporting_condition', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_threshold_config', full_name='config.OnuItuPonAlarm.rate_threshold_config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_range_config', full_name='config.OnuItuPonAlarm.rate_range_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_threshold_config', full_name='config.OnuItuPonAlarm.value_threshold_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ONUITUPONALARM_SOAKTIME, _ONUITUPONALARM_RATETHRESHOLDCONFIG, _ONUITUPONALARM_RATERANGECONFIG, _ONUITUPONALARM_VALUETHRESHOLDCONFIG, ],
  enum_types=[
    _ONUITUPONALARM_ALARMID,
    _ONUITUPONALARM_ALARMREPORTINGCONDITION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config', full_name='config.OnuItuPonAlarm.config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=128,
  serialized_end=1081,
)

_ALARMCONFIG.fields_by_name['onu_itu_pon_alarm_config'].message_type = _ONUITUPONALARM
_ALARMCONFIG.oneofs_by_name['config'].fields.append(
  _ALARMCONFIG.fields_by_name['onu_itu_pon_alarm_config'])
_ALARMCONFIG.fields_by_name['onu_itu_pon_alarm_config'].containing_oneof = _ALARMCONFIG.oneofs_by_name['config']
_ONUITUPONALARM_SOAKTIME.containing_type = _ONUITUPONALARM
_ONUITUPONALARM_RATETHRESHOLDCONFIG.fields_by_name['soak_time'].message_type = _ONUITUPONALARM_SOAKTIME
_ONUITUPONALARM_RATETHRESHOLDCONFIG.containing_type = _ONUITUPONALARM
_ONUITUPONALARM_RATERANGECONFIG.fields_by_name['soak_time'].message_type = _ONUITUPONALARM_SOAKTIME
_ONUITUPONALARM_RATERANGECONFIG.containing_type = _ONUITUPONALARM
_ONUITUPONALARM_VALUETHRESHOLDCONFIG.fields_by_name['soak_time'].message_type = _ONUITUPONALARM_SOAKTIME
_ONUITUPONALARM_VALUETHRESHOLDCONFIG.containing_type = _ONUITUPONALARM
_ONUITUPONALARM.fields_by_name['alarm_id'].enum_type = _ONUITUPONALARM_ALARMID
_ONUITUPONALARM.fields_by_name['alarm_reporting_condition'].enum_type = _ONUITUPONALARM_ALARMREPORTINGCONDITION
_ONUITUPONALARM.fields_by_name['rate_threshold_config'].message_type = _ONUITUPONALARM_RATETHRESHOLDCONFIG
_ONUITUPONALARM.fields_by_name['rate_range_config'].message_type = _ONUITUPONALARM_RATERANGECONFIG
_ONUITUPONALARM.fields_by_name['value_threshold_config'].message_type = _ONUITUPONALARM_VALUETHRESHOLDCONFIG
_ONUITUPONALARM_ALARMID.containing_type = _ONUITUPONALARM
_ONUITUPONALARM_ALARMREPORTINGCONDITION.containing_type = _ONUITUPONALARM
_ONUITUPONALARM.oneofs_by_name['config'].fields.append(
  _ONUITUPONALARM.fields_by_name['rate_threshold_config'])
_ONUITUPONALARM.fields_by_name['rate_threshold_config'].containing_oneof = _ONUITUPONALARM.oneofs_by_name['config']
_ONUITUPONALARM.oneofs_by_name['config'].fields.append(
  _ONUITUPONALARM.fields_by_name['rate_range_config'])
_ONUITUPONALARM.fields_by_name['rate_range_config'].containing_oneof = _ONUITUPONALARM.oneofs_by_name['config']
_ONUITUPONALARM.oneofs_by_name['config'].fields.append(
  _ONUITUPONALARM.fields_by_name['value_threshold_config'])
_ONUITUPONALARM.fields_by_name['value_threshold_config'].containing_oneof = _ONUITUPONALARM.oneofs_by_name['config']
DESCRIPTOR.message_types_by_name['AlarmConfig'] = _ALARMCONFIG
DESCRIPTOR.message_types_by_name['OnuItuPonAlarm'] = _ONUITUPONALARM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AlarmConfig = _reflection.GeneratedProtocolMessageType('AlarmConfig', (_message.Message,), {
  'DESCRIPTOR' : _ALARMCONFIG,
  '__module__' : 'voltha_protos.ext_config_pb2'
  # @@protoc_insertion_point(class_scope:config.AlarmConfig)
  })
_sym_db.RegisterMessage(AlarmConfig)

OnuItuPonAlarm = _reflection.GeneratedProtocolMessageType('OnuItuPonAlarm', (_message.Message,), {

  'SoakTime' : _reflection.GeneratedProtocolMessageType('SoakTime', (_message.Message,), {
    'DESCRIPTOR' : _ONUITUPONALARM_SOAKTIME,
    '__module__' : 'voltha_protos.ext_config_pb2'
    # @@protoc_insertion_point(class_scope:config.OnuItuPonAlarm.SoakTime)
    })
  ,

  'RateThresholdConfig' : _reflection.GeneratedProtocolMessageType('RateThresholdConfig', (_message.Message,), {
    'DESCRIPTOR' : _ONUITUPONALARM_RATETHRESHOLDCONFIG,
    '__module__' : 'voltha_protos.ext_config_pb2'
    # @@protoc_insertion_point(class_scope:config.OnuItuPonAlarm.RateThresholdConfig)
    })
  ,

  'RateRangeConfig' : _reflection.GeneratedProtocolMessageType('RateRangeConfig', (_message.Message,), {
    'DESCRIPTOR' : _ONUITUPONALARM_RATERANGECONFIG,
    '__module__' : 'voltha_protos.ext_config_pb2'
    # @@protoc_insertion_point(class_scope:config.OnuItuPonAlarm.RateRangeConfig)
    })
  ,

  'ValueThresholdConfig' : _reflection.GeneratedProtocolMessageType('ValueThresholdConfig', (_message.Message,), {
    'DESCRIPTOR' : _ONUITUPONALARM_VALUETHRESHOLDCONFIG,
    '__module__' : 'voltha_protos.ext_config_pb2'
    # @@protoc_insertion_point(class_scope:config.OnuItuPonAlarm.ValueThresholdConfig)
    })
  ,
  'DESCRIPTOR' : _ONUITUPONALARM,
  '__module__' : 'voltha_protos.ext_config_pb2'
  # @@protoc_insertion_point(class_scope:config.OnuItuPonAlarm)
  })
_sym_db.RegisterMessage(OnuItuPonAlarm)
_sym_db.RegisterMessage(OnuItuPonAlarm.SoakTime)
_sym_db.RegisterMessage(OnuItuPonAlarm.RateThresholdConfig)
_sym_db.RegisterMessage(OnuItuPonAlarm.RateRangeConfig)
_sym_db.RegisterMessage(OnuItuPonAlarm.ValueThresholdConfig)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
